@@ -1,6 +1,6 @@
 package Net::Twitter::Core;
 
-our $VERSION = '4.01005';
+our $VERSION = '4.01006';
 
 # ABSTRACT: A perl interface to the Twitter API
 
@@ -62,22 +62,8 @@ around BUILDARGS => sub {
 
     my %options = @_ == 1 ? %{$_[0]} : @_;
 
-    # Twitter now requires SSL connections. Since Net::Twitter is used for
-    # Twitter API compatible services that may not require, or indeed allow
-    # SSL, we won't change the default, yet. We'll have a deprecation cycle
-    # where we warn users if they don't have an ssl option set and let them
-    # know enabling ssl will be the default in the future.
-    unless ( exists $options{ssl} ) {
-        warn <<'';
-The Twitter API now requires SSL. Add ( ssl => 1 ) to the options passed to new
-to enable it.  For backwards compatibility, SSL is disabled by default in this
-version. Passing the ssl option to new will disable this warning. If you are
-using a Twitter API compatbile service that does not support SSL, add
-( ssl => 0 ) to disable this warning and preserve non-SSL connections in future
-upgrades.
-
-        $options{ssl} = 0;
-    }
+    # Default to ssl
+    $options{ssl} = 1 unless exists $options{ssl};
 
     # aliases
     for ( [ user => 'username' ], [ pass => 'password' ] ) {
@@ -369,7 +355,7 @@ Net::Twitter::Core - Net::Twitter implementation
 
 =head1 VERSION
 
-version 4.01005
+version 4.01006
 
 =head1 SYNOPSIS
 
